@@ -22,39 +22,48 @@
 */
 #include <qlabel.h>
 #include <qlayout.h>
-
+//Added by qt3to4:
+#include <QVBoxLayout>
+#include <QApplication>
 #include <kgenericfactory.h>
-#include <ksimpleconfig.h>
+#include <kconfig.h>
 #include <kaction.h>
 #include <kiconloader.h>
 #include <kmessagebox.h>
-#include <kiconview.h>
+#include <k3iconview.h>
 #include <kdialog.h>
 #include <klocale.h>
 #include <ktoolbar.h>
-#include <kpopupmenu.h>
+#include <kmenu.h>
 #include <kprotocolinfo.h>
 #include <kdebug.h>
+#include <kactioncollection.h>
 
 #include "kameraconfigdialog.h"
 #include "kameradevice.h"
 #include "kamera.h"
 #include "kamera.moc"
 
-typedef KGenericFactory<KKameraConfig, QWidget> KKameraConfigFactory;
-K_EXPORT_COMPONENT_FACTORY( kcm_kamera, KKameraConfigFactory( "kcmkamera" ) )
+// XXX HACK HACK HACK
+// XXX All tocstr(string) references can be safely replaced with
+// XXX string.latin1() as soon as the gphoto2 API uses 'const char *'
+// XXX instead of 'char *' in calls that don't modify the string
+#define tocstr(x) ((char *)((x).latin1()))
+
+K_PLUGIN_FACTORY(KKameraConfigFactory, registerPlugin<KKameraConfig>();)
+K_EXPORT_PLUGIN(KKameraConfigFactory("kcmkamera"))
 
 // --------------- Camera control center module widget ---
 
 KKameraConfig *KKameraConfig::m_instance = NULL;
 
-KKameraConfig::KKameraConfig(QWidget *parent, const char *name, const QStringList &)
-	: KCModule(KKameraConfigFactory::instance(), parent, name)
+KKameraConfig::KKameraConfig(QWidget *parent, const QVariantList &)
+	: KCModule(KKameraConfigFactory::componentData(), parent/*, name*/)
 {
-	m_devicePopup = new KPopupMenu(this);
+	m_devicePopup = new KMenu(this);
 	m_actions = new KActionCollection(this);
-	m_config = new KSimpleConfig(KProtocolInfo::config("camera"));
-	
+	m_config = new KConfig(KProtocolInfo::config("camera"), KConfig::SimpleConfig);
+
 	m_context = gp_context_new();
 	if (m_context) {
 
@@ -78,67 +87,91 @@ KKameraConfig::KKameraConfig(QWidget *parent, const char *name, const QStringLis
 
 KKameraConfig::~KKameraConfig()
 {
-    delete m_config;
+   delete m_config;
 }
 
 void KKameraConfig::defaults()
 {
-	load( true );
 }
 
 void KKameraConfig::displayGPFailureDialogue(void)
 {
-	new QLabel(i18n("Unable to initialize the gPhoto2 libraries."), this);
+	QVBoxLayout *topLayout = new QVBoxLayout(this);
+	topLayout->setSpacing(0);
+	topLayout->setMargin(0);
+	QLabel *label = new QLabel(i18n("Unable to initialize the gPhoto2 libraries."), this);
+	topLayout->addWidget(label);
 }
 
 void KKameraConfig::displayGPSuccessDialogue(void)
 {
 	// set the kcontrol module buttons
-	setButtons(Help | Apply | Cancel | Ok);
+	setButtons(Help | Apply );
 
 	// create a layout with two vertical boxes
-	QVBoxLayout *topLayout = new QVBoxLayout(this, 0, 0);
-	topLayout->setAutoAdd(true);
-	
-	m_toolbar = new KToolBar(this, "ToolBar");
-	m_toolbar->setMovingEnabled(false);
-	
-	// create list of devices
-	m_deviceSel = new KIconView(this);
+	QVBoxLayout *topLayout = new QVBoxLayout(this);
+	topLayout->setSpacing(0);
+	topLayout->setMargin(0);
 
-	connect(m_deviceSel, SIGNAL(rightButtonClicked(QIconViewItem *, const QPoint &)),
-		SLOT(slot_deviceMenu(QIconViewItem *, const QPoint &)));
-	connect(m_deviceSel, SIGNAL(doubleClicked(QIconViewItem *)),
+	m_toolbar = new KToolBar(this, "ToolBar");
+	topLayout->addWidget(m_toolbar);
+	m_toolbar->setMovable(false);
+
+	// create list of devices
+	m_deviceSel = new K3IconView(this);
+	topLayout->addWidget(m_deviceSel);
+
+	connect(m_deviceSel, SIGNAL(rightButtonClicked(Q3IconViewItem *, const QPoint &)),
+		SLOT(slot_deviceMenu(Q3IconViewItem *, const QPoint &)));
+	connect(m_deviceSel, SIGNAL(doubleClicked(Q3IconViewItem *)),
 		SLOT(slot_configureCamera()));
-	connect(m_deviceSel, SIGNAL(selectionChanged(QIconViewItem *)),
-		SLOT(slot_deviceSelected(QIconViewItem *)));
+	connect(m_deviceSel, SIGNAL(selectionChanged(Q3IconViewItem *)),
+		SLOT(slot_deviceSelected(Q3IconViewItem *)));
 
 	m_deviceSel->setSizePolicy(QSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding));
-	
+
 	// create actions
-	KAction *act;
-	
-	act = new KAction(i18n("Add"), "camera", 0, this, SLOT(slot_addCamera()), m_actions, "camera_add");
+	QAction *act;
+
+	act = m_actions->addAction("camera_add");
+        act->setIcon(KIcon("camera-photo"));
+        act->setText(i18n("Add"));
+	connect(act, SIGNAL(triggered(bool)), this, SLOT(slot_addCamera()));
 	act->setWhatsThis(i18n("Click this button to add a new camera."));
-	act->plug(m_toolbar);
-	m_toolbar->insertLineSeparator();
-	act = new KAction(i18n("Test"), "camera_test", 0, this, SLOT(slot_testCamera()), m_actions, "camera_test");
+	m_toolbar->addAction(act);
+	m_toolbar->addSeparator();
+	act = m_actions->addAction("camera_test");
+        act->setIcon(KIcon("dialog-ok"));
+        act->setText(i18n("Test"));
+	connect(act, SIGNAL(triggered(bool)), this, SLOT(slot_testCamera()));
 	act->setWhatsThis(i18n("Click this button to remove the selected camera from the list."));
-	act->plug(m_toolbar);
-	act = new KAction(i18n("Remove"), "edittrash", 0, this, SLOT(slot_removeCamera()), m_actions, "camera_remove");
+	m_toolbar->addAction(act);
+	act = m_actions->addAction("camera_remove");
+        act->setIcon(KIcon("user-trash"));
+        act->setText(i18n("Remove"));
+	connect(act, SIGNAL(triggered(bool)), this, SLOT(slot_removeCamera()));
 	act->setWhatsThis(i18n("Click this button to remove the selected camera from the list."));
-	act->plug(m_toolbar);
-	act = new KAction(i18n("Configure..."), "configure", 0, this, SLOT(slot_configureCamera()), m_actions, "camera_configure");
+	m_toolbar->addAction(act);
+	act = m_actions->addAction("camera_configure");
+        act->setIcon(KIcon("configure"));
+        act->setText(i18n("Configure..."));
+	connect(act, SIGNAL(triggered(bool)), this, SLOT(slot_configureCamera()));
 	act->setWhatsThis(i18n("Click this button to change the configuration of the selected camera.<br><br>The availability of this feature and the contents of the Configuration dialog depend on the camera model."));
-	act->plug(m_toolbar);
-	act = new KAction(i18n("Information"), "hwinfo", 0, this, SLOT(slot_cameraSummary()), m_actions, "camera_summary");
+	m_toolbar->addAction(act);
+	act = m_actions->addAction("camera_summary");
+        act->setIcon(KIcon("hwinfo"));
+        act->setText(i18n("Information"));
+	connect(act, SIGNAL(triggered(bool)), this, SLOT(slot_cameraSummary()));
 	act->setWhatsThis(i18n("Click this button to view a summary of the current status of the selected camera.<br><br>The availability of this feature and the contents of the Configuration dialog depend on the camera model."));
-	act->plug(m_toolbar);
-	m_toolbar->insertLineSeparator();
-	act = new KAction(i18n("Cancel"), "stop", 0, this, SLOT(slot_cancelOperation()), m_actions, "camera_cancel");
+	m_toolbar->addAction(act);
+	m_toolbar->addSeparator();
+	act = m_actions->addAction("camera_cancel");
+        act->setIcon(KIcon("process-stop"));
+        act->setText(i18n("Cancel"));
+	connect(act, SIGNAL(triggered(bool)), this, SLOT(slot_cancelOperation()));
 	act->setWhatsThis(i18n("Click this button to cancel the current camera operation."));
 	act->setEnabled(false);
-	act->plug(m_toolbar);
+	m_toolbar->addAction(act);
 }
 
 void KKameraConfig::populateDeviceListView(void)
@@ -146,8 +179,8 @@ void KKameraConfig::populateDeviceListView(void)
 	m_deviceSel->clear();
 	CameraDevicesMap::Iterator it;
 	for (it = m_devices.begin(); it != m_devices.end(); it++) {
-		if (it.data()) {
-			new QIconViewItem(m_deviceSel, it.key(), DesktopIcon("camera"));
+		if (it.value()) {
+			new Q3IconViewItem(m_deviceSel, it.key(), DesktopIcon("camera-photo"));
 		}
 	}
 	slot_deviceSelected(m_deviceSel->currentItem());
@@ -159,19 +192,13 @@ void KKameraConfig::save(void)
 
 	for (it = m_devices.begin(); it != m_devices.end(); it++)
 	{
-		it.data()->save(m_config);
+		it.value()->save(m_config);
 	}
 	m_config->sync();
 }
 
 void KKameraConfig::load(void)
 {
-	load( false );
-}
-
-void KKameraConfig::load(bool useDefaults )
-{
-	m_config->setReadDefaults( useDefaults );
 	QStringList groupList = m_config->groupList();
 	QStringList::Iterator it;
         int i, count;
@@ -180,14 +207,14 @@ void KKameraConfig::load(bool useDefaults )
         GPPortInfoList *il;
         const char *model, *value;
 	KCamera *kcamera;
-	
+
 	for (it = groupList.begin(); it != groupList.end(); it++) {
 		if (*it != "<default>")	{
-			m_config->setGroup(*it);
-			if (m_config->readEntry("Path").contains("usb:"))
+			KConfigGroup cg(m_config, *it);
+			if (cg.readEntry("Path").contains("usb:"))
 				continue;
 
-			kcamera = new KCamera(*it,m_config->readEntry("Path"));
+			kcamera = new KCamera(*it, cg.readEntry("Path"));
 			connect(kcamera, SIGNAL(error(const QString &)), SLOT(slot_error(const QString &)));
 			connect(kcamera, SIGNAL(error(const QString &, const QString &)), SLOT(slot_error(const QString &, const QString &)));
 			kcamera->load(m_config);
@@ -209,7 +236,7 @@ void KKameraConfig::load(bool useDefaults )
         count = gp_list_count (list);
 
 	QMap<QString,QString>	ports, names;
-	
+
 	for (i = 0 ; i<count ; i++) {
 		gp_list_get_name  (list, i, &model);
 		gp_list_get_value (list, i, &value);
@@ -224,18 +251,16 @@ void KKameraConfig::load(bool useDefaults )
 	QMap<QString,QString>::iterator portit;
 
 	for (portit = ports.begin() ; portit != ports.end(); portit++) {
-		/* kdDebug() << "Adding USB camera: " << portit.data() << " at " << portit.key() << endl; */
+		/* kDebug() << "Adding USB camera: " << portit.data() << " at " << portit.key(); */
 
-		kcamera = new KCamera(portit.data(),portit.key());
+		kcamera = new KCamera(portit.value(), portit.key());
 		connect(kcamera, SIGNAL(error(const QString &)), SLOT(slot_error(const QString &)));
 		connect(kcamera, SIGNAL(error(const QString &, const QString &)), SLOT(slot_error(const QString &, const QString &)));
-		m_devices[portit.data()] = kcamera;
+		m_devices[portit.value()] = kcamera;
 	}
 	populateDeviceListView();
 
 	gp_list_free (list);
-
-	emit changed( useDefaults );
 }
 
 void KKameraConfig::beforeCameraOperation(void)
@@ -259,7 +284,7 @@ void KKameraConfig::afterCameraOperation(void)
 		qApp->restoreOverrideCursor();
 		m_cancelPending = false;
 	}
-	
+
 	// if any item was selected before the operation was run
 	// it makes sense for the relevant toolbar buttons to be enabled
 	slot_deviceSelected(m_deviceSel->currentItem());
@@ -271,20 +296,20 @@ QString KKameraConfig::suggestName(const QString &name)
 	new_name.replace("/", ""); // we cannot have a slash in a URI's host
 
 	if (!m_devices.contains(new_name)) return new_name;
-	
+
 	// try new names with a number appended until we find a free one
 	int i = 1;
 	while (i++ < 0xffff) {
-		new_name = name + " (" + QString::number(i) + ")";
+		new_name = name + " (" + QString::number(i) + ')';
 		if (!m_devices.contains(new_name)) return new_name;
 	}
 
-	return QString::null;
+	return QString();
 }
 
 void KKameraConfig::slot_addCamera()
 {
-	KCamera *m_device = new KCamera(QString::null,QString::null);
+	KCamera *m_device = new KCamera(QString::null, QString());	//krazy:exclusion=nullstrassign for old broken gcc
 	connect(m_device, SIGNAL(error(const QString &)), SLOT(slot_error(const QString &)));
 	connect(m_device, SIGNAL(error(const QString &, const QString &)), SLOT(slot_error(const QString &, const QString &)));
 	KameraDeviceSelectDialog dialog(this, m_device);
@@ -306,7 +331,7 @@ void KKameraConfig::slot_removeCamera()
 		KCamera *m_device = m_devices[name];
 		m_devices.remove(name);
 		delete m_device;
-		m_config->deleteGroup(name, true);
+		m_config->deleteGroup(name);
 		populateDeviceListView();
 		emit changed(true);
 	}
@@ -322,7 +347,7 @@ void KKameraConfig::slot_testCamera()
 		if (m_device->test())
 			KMessageBox::information(this, i18n("Camera test was successful."));
 	}
-	
+
 	afterCameraOperation();
 }
 
@@ -357,19 +382,19 @@ void KKameraConfig::slot_cancelOperation()
 	qApp->setOverrideCursor(Qt::WaitCursor);
 }
 
-void KKameraConfig::slot_deviceMenu(QIconViewItem *item, const QPoint &point)
+void KKameraConfig::slot_deviceMenu(Q3IconViewItem *item, const QPoint &point)
 {
 	if (item) {
 		m_devicePopup->clear();
-		m_actions->action("camera_test")->plug(m_devicePopup);
-		m_actions->action("camera_remove")->plug(m_devicePopup);
-		m_actions->action("camera_configure")->plug(m_devicePopup);
-		m_actions->action("camera_summary")->plug(m_devicePopup);
+		m_devicePopup->addAction(m_actions->action("camera_test"));
+		m_devicePopup->addAction(m_actions->action("camera_remove"));
+		m_devicePopup->addAction(m_actions->action("camera_configure"));
+		m_devicePopup->addAction(m_actions->action("camera_summary"));
 		m_devicePopup->popup(point);
 	}
 }
 
-void KKameraConfig::slot_deviceSelected(QIconViewItem *item)
+void KKameraConfig::slot_deviceSelected(Q3IconViewItem *item)
 {
 	m_actions->action("camera_test")->setEnabled(item);
 	m_actions->action("camera_remove")->setEnabled(item);
