@@ -25,29 +25,34 @@
 #include <qdir.h>
 #include <qcheckbox.h>
 #include <qcombobox.h>
-#include <qwidgetstack.h>
+#include <QStackedWidget>
+//Added by qt3to4:
+#include <QTextStream>
+#include <QGridLayout>
+#include <QFrame>
+#include <QHBoxLayout>
+#include <QBoxLayout>
+#include <QList>
+#include <QVBoxLayout>
 
 #include <kstandarddirs.h>
 #include <kconfig.h>
 #include <klocale.h>
 #include <kglobal.h>
-#include <kprocess.h>
+#include <k3process.h>
 #include <kdialog.h>
 #include <kgenericfactory.h>
-
-#include "config.h"
+#include <khbox.h>
+#include "config-kgamma.h"
 #include "xf86configpath.h"
 #include "gammactrl.h"
 #include "xvidextwrap.h"
 #include "kgamma.h"
 #include "kgamma.moc"
 
-typedef KGenericFactory<KGamma, QWidget> KGammaFactory;
-K_EXPORT_COMPONENT_FACTORY ( kcm_kgamma, KGammaFactory( "kgamma" ) )
-
 extern "C"
 {
-	bool test_kgamma()
+	bool KDE_EXPORT test_kgamma()
 	{
 		bool retval;
 		(void) new XVidExtWrap(&retval, NULL);
@@ -55,8 +60,14 @@ extern "C"
 	}
 }
 
-KGamma::KGamma(QWidget *parent, const char *name, const QStringList&)
-    :KCModule(parent,name)
+K_PLUGIN_FACTORY(KGammaConfigFactory,
+        registerPlugin<KGamma>();
+        )
+K_EXPORT_PLUGIN(KGammaConfigFactory("kcmkgamma"))
+
+
+KGamma::KGamma(QWidget* parent_P, const QVariantList &)
+    :KCModule(KGammaConfigFactory::componentData(), parent_P)
 {
   bool ok;
   GammaCorrection = true;
@@ -82,7 +93,7 @@ KGamma::KGamma(QWidget *parent, const char *name, const QStringList&)
       }
       xv->setScreen(currentScreen);
 
-      rootProcess = new KProcess;
+      rootProcess = new K3Process;
       setupUI();
       saved = false;
 
@@ -118,15 +129,17 @@ KGamma::~KGamma() {
       }
     delete rootProcess;
   }
-  delete xv;
 }
 
 /** User interface */
 void KGamma::setupUI() {
-  QBoxLayout *topLayout = new QVBoxLayout(this, 0, KDialog::spacingHint());
+  QBoxLayout *topLayout = new QVBoxLayout(this);
+  topLayout->setSpacing(KDialog::spacingHint());
+  topLayout->setMargin(0);
 
   if (GammaCorrection) {
-    QHBoxLayout *hbox = new QHBoxLayout( topLayout );
+    QHBoxLayout *hbox = new QHBoxLayout();
+    topLayout->addItem( hbox );
     QLabel *label = new QLabel( i18n( "&Select test picture:" ) , this);
     QComboBox *combo = new QComboBox( this );
     label->setBuddy( combo );
@@ -138,66 +151,57 @@ void KGamma::setupUI() {
          << i18n( "Dark Gray" )
          << i18n( "Mid Gray" )
          << i18n( "Light Gray" );
-    combo->insertStringList( list );
+    combo->addItems( list );
 
     hbox->addWidget( label );
     hbox->addWidget( combo );
     hbox->addStretch();
 
-    QWidgetStack *stack = new QWidgetStack( this );
+    QStackedWidget  *stack = new QStackedWidget ( this );
     stack->setFrameStyle( QFrame::Box | QFrame::Raised );
 
     connect( combo, SIGNAL( activated( int ) ),
-             stack, SLOT( raiseWidget( int ) ) );
-
-    QPixmap background;
-    background.load(locate("data", "kgamma/pics/background.png"));
+             stack, SLOT( setCurrentIndex( int ) ) );
 
     QLabel *pic1 = new QLabel(stack);
     pic1->setMinimumSize(530, 171);
-    pic1->setBackgroundPixmap(background);
-    pic1->setPixmap(QPixmap(locate("data", "kgamma/pics/greyscale.png")));
-    pic1->setAlignment(AlignCenter);
-    stack->addWidget( pic1, 0 );
+    pic1->setPixmap(QPixmap(KStandardDirs::locate("data", "kgamma/pics/greyscale.png")));
+    pic1->setAlignment(Qt::AlignCenter);
+    stack->insertWidget( 0,pic1 );
 
     QLabel *pic2 = new QLabel(stack);
-    pic2->setBackgroundPixmap(background);
-    pic2->setPixmap(QPixmap(locate("data", "kgamma/pics/rgbscale.png")));
-    pic2->setAlignment(AlignCenter);
-    stack->addWidget( pic2, 1 );
+    pic2->setPixmap(QPixmap(KStandardDirs::locate("data", "kgamma/pics/rgbscale.png")));
+	pic2->setAlignment(Qt::AlignCenter);
+    stack->insertWidget( 1,pic2 );
 
     QLabel *pic3 = new QLabel(stack);
-    pic3->setBackgroundPixmap(background);
-    pic3->setPixmap(QPixmap(locate("data", "kgamma/pics/cmyscale.png")));
-    pic3->setAlignment(AlignCenter);
-    stack->addWidget( pic3, 2 );
+    pic3->setPixmap(QPixmap(KStandardDirs::locate("data", "kgamma/pics/cmyscale.png")));
+    pic3->setAlignment(Qt::AlignCenter);
+    stack->insertWidget( 2,pic3 );
 
     QLabel *pic4 = new QLabel(stack);
-    pic4->setBackgroundPixmap(background);
-    pic4->setPixmap(QPixmap(locate("data", "kgamma/pics/darkgrey.png")));
-    pic4->setAlignment(AlignCenter);
-    stack->addWidget( pic4, 3 );
+    pic4->setPixmap(QPixmap(KStandardDirs::locate("data", "kgamma/pics/darkgrey.png")));
+    pic4->setAlignment(Qt::AlignCenter);
+    stack->insertWidget( 3,pic4 );
 
     QLabel *pic5 = new QLabel(stack);
-    pic5->setBackgroundPixmap(background);
-    pic5->setPixmap(QPixmap(locate("data", "kgamma/pics/midgrey.png")));
-    pic5->setAlignment(AlignCenter);
-    stack->addWidget( pic5, 4 );
+    pic5->setPixmap(QPixmap(KStandardDirs::locate("data", "kgamma/pics/midgrey.png")));
+    pic5->setAlignment(Qt::AlignCenter);
+    stack->insertWidget( 4,pic5 );
 
     QLabel *pic6 = new QLabel(stack);
-    pic6->setBackgroundPixmap(background);
-    pic6->setPixmap(QPixmap(locate("data", "kgamma/pics/lightgrey.png")));
-    pic6->setAlignment(AlignCenter);
-    stack->addWidget( pic6, 5 );
+    pic6->setPixmap(QPixmap(KStandardDirs::locate("data", "kgamma/pics/lightgrey.png")));
+    pic6->setAlignment(Qt::AlignCenter);
+    stack->insertWidget( 5,pic6 );
 
     topLayout->addWidget(stack, 10);
 
     //Sliders for gamma correction
     QFrame *frame1 = new QFrame(this);
-    frame1->setFrameStyle( QFrame::GroupBoxPanel | QFrame::Plain );
+    frame1->setFrameStyle( /*QFrame::GroupBoxPanel |*/ QFrame::Plain );
 
     QFrame *frame2 = new QFrame(this);
-    frame2->setFrameStyle( QFrame::GroupBoxPanel | QFrame::Plain );
+    frame2->setFrameStyle( /*QFrame::GroupBoxPanel |*/ QFrame::Plain );
 
     QLabel *gammalabel = new QLabel(this);
     gammalabel->setText(i18n("Gamma:"));
@@ -237,10 +241,10 @@ void KGamma::setupUI() {
     connect(bgctrl, SIGNAL(gammaChanged(int)), gctrl, SLOT(suspend()));
     bluelabel->setBuddy( bgctrl );
 
-    QGridLayout *grid = new QGridLayout(4, 9);
+    QGridLayout *grid = new QGridLayout();
     grid->setSpacing(8);
-    grid->addMultiCellWidget(frame1, 0, 2, 0, 3);
-    grid->addMultiCellWidget(frame2, 4, 8, 0, 3);
+    grid->addWidget(frame1, 0, 0, 2, 3);
+    grid->addWidget(frame2, 4, 0, 8, 3);
     grid->addWidget(gammalabel, 1, 1, Qt::AlignRight);
     grid->addWidget(redlabel, 5, 1, Qt::AlignRight);
     grid->addWidget(greenlabel, 6, 1, Qt::AlignRight);
@@ -253,9 +257,9 @@ void KGamma::setupUI() {
     topLayout->addLayout(grid);
 
     //Options
-    QHBox *options = new QHBox(this);
+    KHBox *options = new KHBox(this);
 
-    xf86cfgbox = new QCheckBox( i18n("Save settings to XF86Config"), options );
+    xf86cfgbox = new QCheckBox( i18n("Save settings system wide"), options );
     connect(xf86cfgbox, SIGNAL(clicked()), SLOT(changeConfig()));
 
     syncbox = new QCheckBox( i18n("Sync screens"), options );
@@ -264,8 +268,8 @@ void KGamma::setupUI() {
 
     screenselect = new QComboBox( options );
     for ( int i = 0; i < ScreenCount; i++ )
-      screenselect->insertItem( i18n("Screen %1").arg(i+1) );
-    screenselect->setCurrentItem(currentScreen);
+      screenselect->addItem( i18n("Screen %1", i+1) );
+    screenselect->setCurrentIndex(currentScreen);
     connect(screenselect, SIGNAL(activated(int)), SLOT(changeScreen(int)));
 
     options->setSpacing( 10 );
@@ -279,31 +283,24 @@ void KGamma::setupUI() {
     QLabel *error = new QLabel(this);
     error->setText(i18n("Gamma correction is not supported by your"
     " graphics hardware or driver."));
-    error->setAlignment(AlignCenter);
+    error->setAlignment(Qt::AlignCenter);
     topLayout->addWidget(error);
   }
 }
 
-void KGamma::load() {
-	load( false );
-}
-
 /** Restore latest saved gamma values */
-void KGamma::load(bool useDefaults) {
+void KGamma::load() {
   if (GammaCorrection) {
     KConfig *config = new KConfig("kgammarc");
-
-	 config->setReadDefaults( useDefaults );
-
-    config->setGroup("ConfigFile");
+    KConfigGroup group = config->group("ConfigFile");
 
     // save checkbox status
-    if ( xf86cfgbox->isChecked() ) config->writeEntry("use", "XF86Config");
-    else config->writeEntry("use", "kgammarc");
+    if ( xf86cfgbox->isChecked() ) group.writeEntry("use", "XF86Config");
+    else group.writeEntry("use", "kgammarc");
 
     // load syncbox status
-    config->setGroup("SyncBox");
-    if ( config->readEntry("sync") == "yes" ) syncbox->setChecked(true);
+    group = config->group("SyncBox");
+    if ( group.readEntry("sync") == "yes" ) syncbox->setChecked(true);
     else syncbox->setChecked(false);
 
     config->sync();
@@ -330,7 +327,7 @@ void KGamma::load(bool useDefaults) {
     }
     xv->setScreen(currentScreen);
 
-    emit changed(useDefaults);
+    emit changed(false);
   }
 }
 
@@ -345,31 +342,31 @@ void KGamma::save() {
     xv->setScreen(currentScreen);
 
     KConfig *config = new KConfig("kgammarc");
-    config->setGroup("SyncBox");
-    if ( syncbox->isChecked() ) config->writeEntry("sync", "yes");
-    else config->writeEntry("sync", "no");
+    KConfigGroup group = config->group("SyncBox");
+    if ( syncbox->isChecked() ) group.writeEntry("sync", "yes");
+    else group.writeEntry("sync", "no");
 
     if ( !xf86cfgbox->isChecked() ) { //write gamma settings to the users config
       for (int i = 0; i < ScreenCount; i++) {
-        config->setGroup( QString("Screen %1").arg(i) );
-        config->writeEntry("rgamma", rgamma[i]);
-        config->writeEntry("ggamma", ggamma[i]);
-        config->writeEntry("bgamma", bgamma[i]);
+        KConfigGroup screenGroup = config->group( QString("Screen %1").arg(i) );
+        screenGroup.writeEntry("rgamma", rgamma[i]);
+        screenGroup.writeEntry("ggamma", ggamma[i]);
+        screenGroup.writeEntry("bgamma", bgamma[i]);
       }
-      config->setGroup("ConfigFile");
-      config->writeEntry("use", "kgammarc");
+      KConfigGroup confGroup = config->group("ConfigFile");
+      confGroup.writeEntry("use", "kgammarc");
     }
     else {  // write gamma settings to section "Monitor" of XF86Config
-      config->setGroup("ConfigFile");
-      config->writeEntry("use", "XF86Config");
+      KConfigGroup x86group = config->group("ConfigFile");
+      x86group.writeEntry("use", "XF86Config");
 
       if ( !rootProcess->isRunning() ) {
         QString Arguments = "xf86gammacfg ";
         for (int i = 0; i < ScreenCount; i++)
-          Arguments += rgamma[assign[i]] + " " + ggamma[assign[i]] + " " + \
-          bgamma[assign[i]] + " ";
+          Arguments += rgamma[assign[i]] + ' ' + ggamma[assign[i]] + ' ' + \
+                       bgamma[assign[i]] + ' ';
         rootProcess->clearArguments();
-        *rootProcess << "kdesu" << Arguments;
+        *rootProcess << KStandardDirs::findExe("kdesu") << Arguments;
         rootProcess->start();
       }
     }
@@ -381,15 +378,24 @@ void KGamma::save() {
 }
 
 void KGamma::defaults() {
-	load( true );
+  if (GammaCorrection) {
+    for (int i = 0; i < ScreenCount; i++) {
+      xv->setScreen(i);
+      gctrl->setGamma("1.00");
+    }
+    xv->setScreen(currentScreen);
+
+  }
+  xf86cfgbox->setChecked(false);
+  syncbox->setChecked(false);
 }
 
 bool KGamma::loadSettings() {
   KConfig *config = new KConfig("kgammarc");
-  config->setGroup("ConfigFile");
-  QString ConfigFile( config->readEntry("use") );
-  config->setGroup("SyncBox");
-  if ( config->readEntry("sync") == "yes" ) syncbox->setChecked(true);
+  KConfigGroup grp = config->group("ConfigFile");
+  QString ConfigFile( grp.readEntry("use") );
+  KConfigGroup syncGroup = config->group("SyncBox");
+  if ( syncGroup.readEntry("sync") == "yes" ) syncbox->setChecked(true);
   delete config;
 
   if ( ConfigFile == "XF86Config" ) {  // parse XF86Config
@@ -405,10 +411,10 @@ bool KGamma::loadUserSettings() {
   KConfig *config = new KConfig("kgammarc");
 
   for (int i = 0; i < ScreenCount; i++) {
-    config->setGroup(QString( "Screen %1" ).arg(i) );
-    rgamma[i] = config->readEntry("rgamma");
-    ggamma[i] = config->readEntry("ggamma");
-    bgamma[i] = config->readEntry("bgamma");
+    KConfigGroup screenGroup = config->group(QString( "Screen %1" ).arg(i) );
+    rgamma[i] = screenGroup.readEntry("rgamma");
+    ggamma[i] = screenGroup.readEntry("ggamma");
+    bgamma[i] = screenGroup.readEntry("bgamma");
   }
   delete config;
 
@@ -417,22 +423,20 @@ bool KGamma::loadUserSettings() {
 
 bool KGamma::loadSystemSettings() {
   QStringList Monitor, Screen, ScreenLayout, ScreenMonitor, Gamma;
-  QValueList<int> ScreenNr;
+  QList<int> ScreenNr;
   QString Section;
   XF86ConfigPath Path;
-
   QFile f( Path.get() );
-  if ( f.open(IO_ReadOnly) ) {
+  if ( f.open(QIODevice::ReadOnly) ) {
     QTextStream t( &f );
     QString s;
     int sn = 0;
     bool gm = false;
 
     // Analyse Screen<->Monitor assignments of multi-head configurations
-    while ( !t.eof() ) {
-      s = (t.readLine()).simplifyWhiteSpace();
-      QStringList words = QStringList::split(' ', s);
-
+    while ( !t.atEnd() ) {
+      s = (t.readLine()).simplified();
+      QStringList words = s.split(' ');
       if ( !words.empty() ) {
         if ( words[0] == "Section" && words.size() > 1 ) {
           if ( (Section = words[1]) == "\"Monitor\"" ) gm = false;
@@ -475,33 +479,33 @@ bool KGamma::loadSystemSettings() {
       }
     } // End while
     f.close();
-
-    for ( int i = 0; i < ScreenCount; i++ ) {
-      for ( int j = 0; j < ScreenCount; j++ ) {
-        if ( ScreenLayout[i] == Screen[j] ) {
-          for ( int k = 0; k < ScreenCount; k++ ) {
-            if ( Monitor[k] == ScreenMonitor[j] )
-              assign[ScreenNr[i]] = k;
+    if(!Monitor.isEmpty() && !ScreenMonitor.isEmpty() && !ScreenLayout.isEmpty()) {
+      for ( int i = 0; i < ScreenCount; i++ ) {
+        for ( int j = 0; j < ScreenCount; j++ ) {
+          if ( ScreenLayout[i] == Screen[j] ) {
+            for ( int k = 0; k < ScreenCount; k++ ) {
+              if ( Monitor[k] == ScreenMonitor[j] ) {
+                assign[ScreenNr[i]] = k;
+              }
+            }
           }
         }
       }
-    }
+      // Extract gamma values
+      for ( int i = 0; i < ScreenCount; i++) {
+        rgamma[i] = ggamma[i] = bgamma[i] = "";
 
-    // Extract gamma values
-    for ( int i = 0; i < ScreenCount; i++) {
-      rgamma[i] = ggamma[i] = bgamma[i] = "";
-
-      QStringList words = QStringList::split(' ', Gamma[assign[i]]);
-      QStringList::ConstIterator it = words.begin();
-      if ( words.size() < 4 )
-        rgamma[i] = ggamma[i] = bgamma[i] = *(++it);   // single gamma value
-      else  {
-        rgamma[i] = *(++it);  // eventually rgb gamma values
-        ggamma[i] = *(++it);
-        bgamma[i] = *(++it);
+        QStringList words = Gamma[assign[i]].split(' ');
+        QStringList::ConstIterator it = words.begin();
+        if ( words.size() < 4 )
+          rgamma[i] = ggamma[i] = bgamma[i] = *(++it);   // single gamma value
+        else  {
+          rgamma[i] = *(++it);  // eventually rgb gamma values
+          ggamma[i] = *(++it);
+          bgamma[i] = *(++it);
+         }
+       }
       }
-    }
-
   }
   return( validateGammaValues() );
 }
@@ -610,13 +614,13 @@ extern "C"
 
       for (int i = 0; i < xv._ScreenCount(); i++) {
         xv.setScreen(i);
-        config->setGroup( QString("Screen %1").arg(i) );
+        KConfigGroup screenGroup = config->group( QString("Screen %1").arg(i) );
 
-        if ((rgamma = config->readEntry("rgamma").toFloat()))
+        if ((rgamma = screenGroup.readEntry("rgamma").toFloat()))
           xv.setGamma(XVidExtWrap::Red, rgamma);
-        if ((ggamma = config->readEntry("ggamma").toFloat()))
+        if ((ggamma = screenGroup.readEntry("ggamma").toFloat()))
           xv.setGamma(XVidExtWrap::Green, ggamma);
-        if ((bgamma = config->readEntry("bgamma").toFloat()))
+        if ((bgamma = screenGroup.readEntry("bgamma").toFloat()))
           xv.setGamma(XVidExtWrap::Blue, bgamma);
       }
       delete config;
