@@ -163,7 +163,7 @@ static KAboutData createAboutData()
          "okular_tiff",
          "okular_tiff",
          ki18n( "TIFF Backend" ),
-         "0.2.1",
+         "0.2.2",
          ki18n( "A TIFF backend" ),
          KAboutData::License_GPL,
          ki18n( "© 2006-2008 Pino Toscano" ),
@@ -421,7 +421,16 @@ bool TIFFGenerator::print( QPrinter& printer )
         if ( i != 0 )
             printer.newPage();
 
-        p.drawImage( 0, 0, image );
+        QSize targetSize = printer.pageRect().size();
+
+        if ( (image.width() < targetSize.width()) && (image.height() < targetSize.height()) )
+        {
+            // draw small images at 100% (don't scale up)
+            p.drawImage( 0, 0, image );
+        } else {
+            // fit to page
+            p.drawImage( 0, 0, image.scaled( targetSize, Qt::IgnoreAspectRatio, Qt::SmoothTransformation ) );
+        }
     }
 
     return true;
